@@ -449,6 +449,7 @@ void ass_process_force_style(ASS_Track *track)
                     FPVAL(Angle)
                     INTVAL(BorderStyle)
                     INTVAL(Alignment)
+                    INTVAL(Justify)
                     INTVAL(MarginL)
                     INTVAL(MarginR)
                     INTVAL(MarginV)
@@ -621,6 +622,7 @@ static int process_info_line(ASS_Track *track, char *str)
     } else if (!strncmp(str, "Language:", 9)) {
         char *p = str + 9;
         while (*p && ass_isspace(*p)) p++;
+        free(track->Language);
         track->Language = strndup(p, 2);
     }
     return 0;
